BioPortalAligner
================

.. currentmodule:: bioregistry.align

.. autoclass:: BioPortalAligner
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~BioPortalAligner.curation_header
      ~BioPortalAligner.key

   .. rubric:: Methods Summary

   .. autosummary::

      ~BioPortalAligner.get_curation_row
      ~BioPortalAligner.getter
      ~BioPortalAligner.prepare_external

   .. rubric:: Attributes Documentation

   .. autoattribute:: curation_header
   .. autoattribute:: key

   .. rubric:: Methods Documentation

   .. automethod:: get_curation_row
   .. automethod:: getter
   .. automethod:: prepare_external
